@@ -5,7 +5,8 @@ from json.decoder import JSONDecoder, JSONDecodeError
 
 import boto3
 
-GZIP_AUTO=object()
+GZIP_AUTO = object()
+
 
 def object_stream(f, decoder=None, bufsize=64 * 1024):
     idx = 0
@@ -40,28 +41,33 @@ def object_stream(f, decoder=None, bufsize=64 * 1024):
 
 def list_files(s3, bucket, prefix):
     files = {
-        'IsTruncated': True,
+        "IsTruncated": True,
     }
 
-    while files['IsTruncated']:
-        if 'NextContinuationToken' in files:
-            files = s3.list_objects_v2(Bucket=bucket, Prefix=prefix, ContinuationToken=files['NextContinuationToken'])
+    while files["IsTruncated"]:
+        if "NextContinuationToken" in files:
+            files = s3.list_objects_v2(
+                Bucket=bucket,
+                Prefix=prefix,
+                ContinuationToken=files["NextContinuationToken"],
+            )
         else:
             files = s3.list_objects_v2(Bucket=bucket, Prefix=prefix)
-        if 'Contents' in files:
-            yield from [f['Key'] for f in files['Contents']]
+        if "Contents" in files:
+            yield from [f["Key"] for f in files["Contents"]]
         else:
             return
 
 
-
 def stream(bucket, key, s3, use_gzip):
-    use_gzip = key.endswith('.gz') if use_gzip == GZIP_AUTO else use_gzip
-    print(use_gzip)
     data = s3.get_object(Key=key, Bucket=bucket)
+    if use_gzip == GZIP_AUTO:
+        use_gzip = data.get("ContentEncoding") == "gzip"
+
     if use_gzip:
-        return gzip.open(data['Body'], mode='rt')
-    return io.TextIOWrapper(data['Body'])
+        return gzip.open(data["Body"], mode="rt")
+
+    return io.TextIOWrapper(data["Body"])
 
 
 def sip(*, bucket=None, prefix=None, key=None, s3=None, gzip=GZIP_AUTO):
@@ -69,7 +75,7 @@ def sip(*, bucket=None, prefix=None, key=None, s3=None, gzip=GZIP_AUTO):
     if (key and prefix) or not (key or prefix):
         raise ValueError("You must provide either a key or prefix")
 
-    s3 = s3 or boto3.client('s3')
+    s3 = s3 or boto3.client("s3")
 
     if key:
         yield from object_stream(stream(bucket, key, s3, gzip))
